import { modelOptions, prop } from '@typegoose/typegoose';
import { Base } from '@typegoose/typegoose/lib/defaultClasses';

export type Tier = 1 | 2 | 3;

class Permissions {
  @prop()
  staff?: boolean;

  @prop()
  technician?: boolean;

  @prop()
  director?: boolean;
}

@modelOptions({ schemaOptions: { collection: 'Account' } })
export default class Account extends Base {
  @prop({ required: true, unique: true })
  username: string;

  @prop({ required: true, unique: true })
  userID: string;

  @prop({ required: true, unique: true })
  homepath: string;

  @prop({ required: true })
  emailAddress: string;

  @prop({ required: true })
  createdBy: string;

  @prop({ required: true })
  createdAt: Date;

  @prop({ required: true, default: false })
  locked: boolean;

  @prop({ required: true, default: 1 })
  tier: Tier;

  @prop({ required: true })
  supportKey: string;

  @prop({ required: true, unique: true })
  referralCode: string;

  @prop({ required: true, default: 0 })
  totalReferrals: number;

  @prop()
  permissions?: Permissions;

  @prop()
  ramLimitNotification: number;

  @prop()
  root: boolean;

  @prop()
  hash: boolean;

  @prop()
  salt: string;

  @prop()
  authTag: Buffer;

  @prop({ type: () => String })
  revokedBearers: string[];
}
